@@ -3,10 +3,13 @@ from __future__ import unicode_literals
 import random
 import hashlib
 import datetime
+import unittest
 
+from django.core.urlresolvers import resolve, reverse
 from django.contrib.auth import get_user_model
 from django.core.exceptions import ValidationError
-from django.test import TestCase
+from django import test
+from django.http import HttpRequest
 
 from verification.models import *
 from verification.views import *
@@ -22,7 +25,7 @@ from verification.generators import (
     SHORT_LENGTH,
 )
 
-class RegistryTest(TestCase):
+class RegistryTest(unittest.TestCase):
 
     def setUp(self):
         registry = Registry()
@@ -64,7 +67,7 @@ class RegistryTest(TestCase):
         registry.reset()
         self.assertEqual(set(registry.available()), set(expected))
 
-class AbstractKeyGeneratorTest(TestCase):
+class AbstractKeyGeneratorTest(unittest.TestCase):
 
     def tearDown(self):
         registry = Registry()
@@ -106,7 +109,7 @@ class AbstractKeyGeneratorTest(TestCase):
         gen.unregister()
         self.assertRaises(GeneratorError, registry.get, 'abstract')
 
-class AbstractAlphabetKeyGeneratorTest(TestCase):
+class AbstractAlphabetKeyGeneratorTest(unittest.TestCase):
 
     def test_init(self):
         gen = AbstractAlphabetKeyGenerator()
@@ -129,7 +132,7 @@ class AbstractAlphabetKeyGeneratorTest(TestCase):
         key = gen.generate_one_key()
         self.assertEqual(expected_key, key)
 
-class HashedHexKeyGeneratorTest(TestCase):
+class HashedHexKeyGeneratorTest(unittest.TestCase):
 
     def test_init(self):
         gen = HashedHexKeyGenerator()
@@ -148,7 +151,7 @@ class HashedHexKeyGeneratorTest(TestCase):
         expected_key = '98397f5b411802bac598c3f0a19cd7c3063461ca'
         self.assertEqual(expected_key, key)
 
-class KeyGroupTest(TestCase):
+class KeyGroupTest(test.TestCase):
 
     def setUp(self):
         self.kg_sms = KeyGroup.objects.create(name='test1', generator='sms')
@@ -185,7 +188,7 @@ class KeyGroupTest(TestCase):
         self.assertEqual(k.key, 'Aa1txnLk')
         self.assertEqual(k.fact, fact)
 
-class KeyTest(TestCase):
+class KeyTest(test.TestCase):
 
     def setUp(self):
         self.kg_sms = KeyGroup.objects.create(name='sms', generator='sms')
@@ -296,7 +299,7 @@ class KeyTest(TestCase):
         self.assertEqual(k.group, self.kg_sms)
         self.assertEqual(k.fact, fact)
 
-class ClaimTest(TestCase):
+class ClaimTest(test.TestCase):
 
     def setUp(self):
         self.kg = KeyGroup.objects.create(name='sms')
@@ -323,10 +326,34 @@ class ClaimTest(TestCase):
         k1 = Key.objects.create(key='1', group=self.kg, expires=earlier)
         self.assertRaises(VerificationError, claim, '1', self.user)
 
-class AdminTest(TestCase):
+class AdminTest(unittest.TestCase):
 
     def test_all_defined(self):
         try:
             import verification.admin
         except (NameError, AssertionError) as e:
             self.fail(e)
+
+class ClaimSuccessViewTest(test.TestCase):
+
+    def setUp(self):
+        self.kg = KeyGroup.objects.create(name='sms')
+        self.k = Key.objects.create(key='blabla', group=self.kg)
+        self.factory = test.RequestFactory()
+
+    def test_find_view(self):
+        kwargs = {
+            'key': self.k.key,
+            'group': self.kg.name
+        }
+        found = resolve(reverse('verification-success', kwargs=kwargs))
+        self.assertEqual(found.func, claim_success)
+
+    def test_not500(self):
+        kwargs = {
+            'key': self.k.key,
+            'group': self.kg.name
+        }
+        request = self.factory.get(reverse('verification-success', kwargs=kwargs))
+        response = claim_success(request, **kwargs)
+        self.assertNotEqual(response.status_code, 500)
